import axios, { isAxiosError } from 'axios';
import { useEffect, useState, useCallback } from 'react';

const useAxios = (url, dependencies = [], options = { method: "GET" }) => {
    const { execute, refetch, reset, ...state } = useAxiosInternal(url, options, dependencies, true);
    useEffect(() => {
        execute();
    }, dependencies);
    return state;
};
const useAxiosFn = (url, options = { method: "GET" }, dependencies = []) => {
    return useAxiosInternal(url, options, dependencies, false);
};
const useAxiosInternal = (url, options, dependencies, initialLoading) => {
    const [data, setData] = useState(null);
    const [loading, setLoading] = useState(initialLoading);
    const [error, setError] = useState(null);
    const execute = useCallback(async () => {
        setLoading(true);
        try {
            const { data } = await axios(url, options);
            setData(data);
        }
        catch (error) {
            let errorObj = {
                status: error.response?.status,
                message: isAxiosError(error)
                    ? error.response?.data.message
                    : "Some went wrong!",
            };
            setError(errorObj);
        }
        finally {
            setLoading(false);
        }
    }, dependencies);
    const refetch = () => {
        setLoading(true);
        setData(null);
    };
    const reset = () => {
        setData(null);
        setError(null);
        setLoading(false);
    };
    return { data, loading, refetch, error, execute, reset };
};

export { useAxios, useAxiosFn };
